Changelog
==============

1.1.0
------
* jQuery updated to v1.10.2 and v2.0.3
* jQuery smooth-scroll updated to v.1.4.11
* Twitter Bootstrap (TWBS) updated to v3.0.0 RC1
* TWBS typeahead, glyphicons and bootstrap-responsive removed per TWBS v3.0.0 RC1

1.0.1
------
* Moved Silk icons out of recursive img dirs.

1.0.0
------
* There was some wide-sweeping, non-backwards compatible changes - read carefully!
* Packaged renamed to djfrontend. This will affect INSTALLED_APPS settings as well as the static location.
* Icons now included in the default setup.
* Template tags renamed to djfrontend.py.
* {% load djfrontend %} loads all template tags.

0.1.0
------
* Initial release